@@ -34,17 +34,17 @@ Rcpp::List sde_state_sampler_bsf_is2(const arma::vec& y, const double x0,
     arma::mat weights_i(nsim_states, model.n + 1);
     arma::umat indices(nsim_states, model.n);
     double loglik = model.bsf_filter(nsim_states, L_f, alpha_i, weights_i, indices);
-    if(arma::is_finite(loglik)) {
+    // if(arma::is_finite(loglik)) {
       weights(i) = std::exp(loglik - approx_loglik_storage(i));
       
       filter_smoother(alpha_i, indices);
       arma::vec w = weights_i.col(model.n);
       std::discrete_distribution<unsigned int> sample(w.begin(), w.end());
       alpha.slice(i) = alpha_i.slice(sample(model.engine)).t();
-    } else {
-      weights(i) = 0.0;
-      alpha.slice(i).zeros();
-    }
+    // } else {
+    //   weights(i) = 0.0;
+    //   alpha.slice(i).zeros();
+    // }
   }
   return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
     Rcpp::Named("weights") = weights);
