@@ -8,17 +8,17 @@
 #include "rep_mat.h"
 
 #include "filter_smoother.h"
+#include "summary.h"
 
 sde_amcmc::sde_amcmc(const unsigned int n_iter, 
   const unsigned int n_burnin, const unsigned int n_thin, const unsigned int n, 
   const double target_acceptance, const double gamma, 
-  const arma::mat& S) :
+  const arma::mat& S, const unsigned int output_type) :
   mcmc(n_iter, n_burnin, n_thin, n, 1,
-    target_acceptance, gamma, S, true),
+    target_acceptance, gamma, S, output_type),
     weight_storage(arma::vec(n_samples, arma::fill::zeros)),
     approx_loglik_storage(arma::vec(n_samples)),
-    prior_storage(arma::vec(n_samples)),
-    iter_storage(arma::uvec(n_samples)){
+    prior_storage(arma::vec(n_samples)){
 }
 
 void sde_amcmc::trim_storage() {
@@ -31,7 +31,6 @@ void sde_amcmc::trim_storage() {
     weight_storage.resize(n_stored);
     approx_loglik_storage.resize(n_stored);
     prior_storage.resize(n_stored);
-    iter_storage.resize(n_stored);
   }
 }
 
@@ -64,9 +63,6 @@ void sde_amcmc::expand() {
   prior_storage.set_size(n_stored);
   prior_storage = expanded_prior;
   
-  arma::uvec expanded_iter = rep_uvec(iter_storage, count_storage);
-  iter_storage.set_size(n_stored);
-  iter_storage = expanded_iter;
   
   count_storage.resize(n_stored);
   count_storage.ones();
@@ -146,7 +142,6 @@ void sde_amcmc::approx_mcmc(sde_ssm model, const bool end_ram,
         prior_storage(n_stored) = logprior;
         theta_storage.col(n_stored) = theta;
         count_storage(n_stored) = 1;
-        iter_storage(n_stored) = i; //count 0 as well
         n_stored++;
         new_value = false;
       } else {
@@ -167,9 +162,12 @@ void sde_amcmc::is_correction_bsf(sde_ssm model, const unsigned int nsim_states,
   const unsigned int L_c, const unsigned int L_f, 
   const unsigned int is_type, const unsigned int n_threads) {
   
+  arma::cube Valpha(1, 1, model.n + 1, arma::fill::zeros);
+  double sum_w = 0.0;
+  
 #ifdef _OPENMP
-#pragma omp parallel num_threads(n_threads) default(none) firstprivate(model) 
-  {
+#pragma omp parallel num_threads(n_threads) default(none) shared(Valpha, sum_w) firstprivate(model) 
+{
   
   model.engine = sitmo::prng_engine(omp_get_thread_num() + 1);
   model.coarse_engine = sitmo::prng_engine(omp_get_thread_num() + n_threads + 1);
@@ -185,16 +183,30 @@ void sde_amcmc::is_correction_bsf(sde_ssm model, const unsigned int nsim_states,
     arma::mat weights_i(nsim, model.n + 1);
     arma::umat indices(nsim, model.n);
     double loglik = model.bsf_filter(nsim, L_f, alpha_i, weights_i, indices);
-    if(arma::is_finite(loglik)) {
-      weight_storage(i) = std::exp(loglik - approx_loglik_storage(i));
-      
+    weight_storage(i) = std::exp(loglik - approx_loglik_storage(i));
+    
+    if (output_type != 3) {
       filter_smoother(alpha_i, indices);
       arma::vec w = weights_i.col(model.n);
-      std::discrete_distribution<unsigned int> sample(w.begin(), w.end());
-      alpha_storage.slice(i) = alpha_i.slice(sample(model.engine)).t();
-    } else {
-      weight_storage(i) = 0.0;
-      alpha_storage.slice(i).zeros();
+      if (output_type == 1) {
+        std::discrete_distribution<unsigned int> sample(w.begin(), w.end());
+        alpha_storage.slice(i) = alpha_i.slice(sample(model.engine)).t();
+      } else {
+        arma::mat alphahat_i(1, model.n + 1);
+        arma::cube Vt_i(1, 1, model.n + 1);
+        weighted_summary(alpha_i, alphahat_i, Vt_i, w);
+#pragma omp critical
+{
+  arma::mat diff = alphahat_i - alphahat;
+  double tmp = count_storage(i) + sum_w;
+  alphahat = (alphahat * sum_w + alphahat_i * count_storage(i)) / tmp;
+  for (unsigned int t = 0; t < model.n + 1; t++) {
+    Valpha.slice(t) += diff.col(t) * (alphahat_i.col(t) - alphahat.col(t)).t();
+  }
+  Vt = (Vt * sum_w + Vt_i * count_storage(i)) / tmp;
+  sum_w = tmp;
+}
+      }
     }
   }
 }
@@ -209,18 +221,34 @@ for (unsigned int i = 0; i < n_stored; i++) {
   arma::mat weights_i(nsim, model.n + 1);
   arma::umat indices(nsim, model.n);
   double loglik = model.bsf_filter(nsim, L_f, alpha_i, weights_i, indices);
-  if(arma::is_finite(loglik)) {
-    weight_storage(i) = std::exp(loglik - approx_loglik_storage(i));
-    
+  weight_storage(i) = std::exp(loglik - approx_loglik_storage(i));
+  
+  if (output_type != 3) {
     filter_smoother(alpha_i, indices);
     arma::vec w = weights_i.col(model.n);
-    std::discrete_distribution<unsigned int> sample(w.begin(), w.end());
-    alpha_storage.slice(i) = alpha_i.slice(sample(model.engine)).t();
-  } else {
-    weight_storage(i) = 0.0;
-    alpha_storage.slice(i).zeros();
+    if (output_type == 1) {
+      std::discrete_distribution<unsigned int> sample(w.begin(), w.end());
+      alpha_storage.slice(i) = alpha_i.slice(sample(model.engine)).t();
+    } else {
+      arma::mat alphahat_i(1, model.n + 1);
+      arma::cube Vt_i(1, 1, model.n + 1);
+      weighted_summary(alpha_i, alphahat_i, Vt_i, w);
+      
+      arma::mat diff = alphahat_i - alphahat;
+      double tmp = count_storage(i) + sum_w;
+      alphahat = (alphahat * sum_w + alphahat_i * count_storage(i)) / tmp;
+      for (unsigned int t = 0; t < model.n + 1; t++) {
+        Valpha.slice(t) += diff.col(t) * (alphahat_i.col(t) - alphahat.col(t)).t();
+      }
+      Vt = (Vt * sum_w + Vt_i * count_storage(i)) / tmp;
+      sum_w = tmp;
+      
+    }
   }
 }
 #endif
+if (output_type == 2) {
+  Vt += Valpha / theta_storage.n_cols; // Var[E(alpha)] + E[Var(alpha)]
+}
 posterior_storage = prior_storage + approx_loglik_storage + arma::log(weight_storage);
 }
